@@ -9,6 +9,7 @@ from typing import Any, Coroutine, Dict, Optional, Tuple, Type, Union
 
 from Crypto.Cipher import AES
 from crccheck.crc import CrcX25
+
 from zigpy.exceptions import ControllerException, ZigbeeException
 import zigpy.types as t
 
@@ -285,7 +286,7 @@ class CatchingTaskMixin(LocalLogMixin):
             return await target
         except exceptions:
             pass
-        except Exception:  # pylint: disable=broad-except
+        except (Exception, asyncio.CancelledError):  # pylint: disable=broad-except
             # Do not print the wrapper in the traceback
             frames = len(inspect.trace()) - 1
             exc_msg = traceback.format_exc(-frames)
