@@ -62,6 +62,7 @@ class Cluster(util.ListenableMixin, util.CatchingTaskMixin, metaclass=Registry):
     _client_commands_idx: Dict[str, int] = {}
     attridx: Dict[str, int]
     attributes: Dict[int, Tuple[str, Callable]] = {}
+    ep_attribute: str = None
     client_commands: Dict[int, Tuple[str, Tuple, bool]] = {}
     server_commands: Dict[int, Tuple[str, Tuple, bool]] = {}
 
@@ -187,20 +188,42 @@ class Cluster(util.ListenableMixin, util.CatchingTaskMixin, metaclass=Registry):
 
         return self._endpoint.reply(self.cluster_id, tsn, data, command_id=command_id)
 
-    def handle_message(self, hdr, args):
+    def handle_message(
+        self,
+        hdr: foundation.ZCLHeader,
+        args: List[Any],
+        *,
+        dst_addressing: Optional[
+            Union[t.Addressing.Group, t.Addressing.IEEE, t.Addressing.NWK]
+        ] = None,
+    ):
         self.debug("ZCL request 0x%04x: %s", hdr.command_id, args)
         if hdr.frame_control.is_cluster:
-            self.handle_cluster_request(hdr.tsn, hdr.command_id, args)
+            self.handle_cluster_request(hdr, args, dst_addressing=dst_addressing)
             self.listener_event("cluster_command", hdr.tsn, hdr.command_id, args)
             return
         self.listener_event("general_command", hdr, args)
-        self.handle_cluster_general_request(hdr, args)
+        self.handle_cluster_general_request(hdr, args, dst_addressing=dst_addressing)
 
-    def handle_cluster_request(self, tsn, command_id, args):
-        self.debug("No handler for cluster command %s", command_id)
+    def handle_cluster_request(
+        self,
+        hdr: foundation.ZCLHeader,
+        args: List[Any],
+        *,
+        dst_addressing: Optional[
+            Union[t.Addressing.Group, t.Addressing.IEEE, t.Addressing.NWK]
+        ] = None,
+    ):
+        self.debug("No handler for cluster command %s", hdr.command_id)
 
     def handle_cluster_general_request(
-        self, hdr: foundation.ZCLHeader, args: List
+        self,
+        hdr: foundation.ZCLHeader,
+        args: List,
+        *,
+        dst_addressing: Optional[
+            Union[t.Addressing.Group, t.Addressing.IEEE, t.Addressing.NWK]
+        ] = None,
     ) -> None:
         if hdr.command_id == foundation.Command.Report_Attributes:
             valuestr = ", ".join(
@@ -226,13 +249,9 @@ class Cluster(util.ListenableMixin, util.CatchingTaskMixin, metaclass=Registry):
                 self._update_attribute(attr.attrid, value)
 
             if not hdr.frame_control.disable_default_response:
-                self.create_catching_task(
-                    self.general_command(
-                        foundation.Command.Default_Response,
-                        hdr.command_id,
-                        foundation.Status.SUCCESS,
-                        tsn=hdr.tsn,
-                    )
+                self.send_default_rsp(
+                    hdr,
+                    foundation.Status.SUCCESS,
                 )
 
     def read_attributes_raw(self, attributes, manufacturer=None):
@@ -240,7 +259,11 @@ class Cluster(util.ListenableMixin, util.CatchingTaskMixin, metaclass=Registry):
         return self._read_attributes(attributes, manufacturer=manufacturer)
 
     async def read_attributes(
-        self, attributes, allow_cache=False, only_cache=False, manufacturer=None,
+        self,
+        attributes,
+        allow_cache=False,
+        only_cache=False,
+        manufacturer=None,
     ):
         success, failure = {}, {}
         attribute_ids = []
@@ -441,6 +464,7 @@ class Cluster(util.ListenableMixin, util.CatchingTaskMixin, metaclass=Registry):
         *args,
         manufacturer: Optional[Union[int, t.uint16_t]] = None,
         expect_reply: bool = True,
+        tries: int = 1,
         tsn: Optional[Union[int, t.uint8_t]] = None,
     ):
         schema = self.server_commands[command_id][1]
@@ -451,6 +475,7 @@ class Cluster(util.ListenableMixin, util.CatchingTaskMixin, metaclass=Registry):
             *args,
             manufacturer=manufacturer,
             expect_reply=expect_reply,
+            tries=tries,
             tsn=tsn,
         )
 
@@ -511,6 +536,19 @@ class Cluster(util.ListenableMixin, util.CatchingTaskMixin, metaclass=Registry):
         else:
             raise AttributeError("No such command name: %s" % (name,))
 
+    def get(self, key: Union[int, str], default: Optional[Any] = None) -> Any:
+        """Get cached attribute."""
+        if isinstance(key, int):
+            return self._attr_cache.get(key, default)
+        elif isinstance(key, str):
+            try:
+                attr_id = self.attridx[key]
+            except KeyError:
+                return default
+            return self._attr_cache.get(attr_id, default)
+
+        raise ValueError("attr_name or attr_id are accepted only")
+
     def __getitem__(self, key: Union[int, str]) -> Any:
         """Return cached value of the attr."""
         if isinstance(key, int):
@@ -580,6 +618,21 @@ class Cluster(util.ListenableMixin, util.CatchingTaskMixin, metaclass=Registry):
         general_command, foundation.Command.Discover_Commands_Generated
     )
 
+    def send_default_rsp(
+        self,
+        hdr: foundation.ZCLHeader,
+        status: foundation.Status = foundation.Status.SUCCESS,
+    ) -> None:
+        """Send default response unconditionally."""
+        self.create_catching_task(
+            self.general_command(
+                foundation.Command.Default_Response,
+                hdr.command_id,
+                status,
+                tsn=hdr.tsn,
+            )
+        )
+
 
 class ClusterPersistingListener:
     def __init__(self, applistener, cluster):
@@ -597,4 +650,4 @@ class ClusterPersistingListener:
 
 
 # Import to populate the registry
-from . import clusters  # noqa: F401, F402, isort:skip
+from . import clusters  # noqa: F401, E402, isort:skip
